Documentation
¶
Overview ¶
Package helper contains various helper functions.
Index ¶
- Variables
- func CreateDirIfNotExist(dir string) error
- func DeserializeRepo(gitRepo string) (repoURL string, branch string, completeUrl string)
- func Env(key, fallback string) string
- func FileExists(filename string) bool
- func Hash(payload, secret, hashType string) (string, error)
- func SerializeRepo(repoName string, branch string) string
- func WriteToFile(filePath, text string) error
Constants ¶
This section is empty.
Variables ¶
var ( DeployCount int32 = 0 StopCount int32 = 0 LogsCount int32 = 0 RedeployCount int32 = 0 )
DeployCount is the global number of deploy requests handled
Functions ¶
func CreateDirIfNotExist ¶
CreateDirIfNotExist creates a given directory if it does not exist
func DeserializeRepo ¶
func Env ¶
Env returns the value of the environment variable if present, or returns the fallback value
func SerializeRepo ¶
func WriteToFile ¶
WriteToFile writes a given string to a file. It creates the file if it is not present
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.